/****************************************************************************
** Interface to the GUI.
**
** Created: Mon Jun 07 22:48:00 2004
**      by: Varol Okan using kate editor
**
**
****************************************************************************/

#ifndef DIALOGCOMMANDEDITOR_H
#define DIALOGCOMMANDEDITOR_H


// the designer created GUI.
#include "uicommandeditor.h"
#include "qdvdauthorinit.h"

class DialogCommandEditor : public uiDialogCommandEditor
{
	Q_OBJECT
public:
	 DialogCommandEditor ( QWidget *, const char *n=0, WFlags f=0 );
	~DialogCommandEditor ( );

	void initMe ( QDVDAuthorInit::MenuBlock::Block *, uint );
	void initMe ( QDVDAuthorInit::MenuBlock::Block *, uint, QStringList, uint i=0 );

private slots:
	virtual void slotAddCommand    ( );
	virtual void slotAddToCommand  ( );
	virtual void slotDeleteCommand ( );
	virtual void slotCheckDefault  ( );

private:
	virtual void accept ( );

	void addCommandTab( QString );

private:
	QDVDAuthorInit::MenuBlock::Block *m_pCommandBlock;
	QValueList<QWidget *>   m_listCommandTabs;
	QValueList<QCheckBox *> m_listCheckDefault;
	QValueList<QTextEdit *> m_listEditCommands;
};

#endif // DIALOGCOMMANDEDITOR_H

